@@ -68,6 +68,8 @@ static layouts layout_names[] = {
     {"bg_phonetic",	"Български - Phonetic"},
     {"faen",		"Persian, English"},
     {"mk",		"Македонски"},
+    {"ru_phonetic",	"Русский - Phonetic"},
+    {"he_phonetic",	"עברית - Phonetic"},
     {NULL,		NULL}
 };
 
